@@ -310,13 +310,13 @@ class Neo4jCsvPublisherApoc(Publisher):
         if self.is_create_only_node(node_records[0]):
             return """            
                     CALL apoc.periodic.iterate('UNWIND $rows AS row RETURN row', '
-                        CALL apoc.merge.node([row.label], {key:row.key}, row, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}) YIELD node RETURN COUNT(*);
+                        CALL apoc.merge.node([row.LABEL], {key:row.KEY}, row, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}) YIELD node RETURN COUNT(*);
                     ', {batchSize: $batch_size, iterateList: True, parallel: False, params: { rows: $batch, tag: $publish_tag }})
                 """
 
         return """            
             CALL apoc.periodic.iterate('UNWIND $rows AS row RETURN row', '
-                CALL apoc.merge.node([row.label], {key:row.key}, row, row) YIELD node RETURN COUNT(*);
+                CALL apoc.merge.node([row.LABEL], {key:row.KEY}, row, row) YIELD node RETURN COUNT(*);
             ', {batchSize: $batch_size, iterateList: True, parallel: False, params: { rows: $batch }})
         """
 
@@ -397,10 +397,10 @@ class Neo4jCsvPublisherApoc(Publisher):
         # TODO: check out https://neo4j.com/docs/cypher-manual/current/query-tuning/advanced-example/
         return """            
             CALL apoc.periodic.iterate('UNWIND $rows AS row RETURN row', '
-                CALL apoc.merge.node([row.start_label], {key:row.start_key}) YIELD node AS n1
-                CALL apoc.merge.node([row.end_label], {key:row.end_key}) YIELD node AS n2
-                CALL apoc.merge.relationship(n1, row.type, {}, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}, n2, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}) YIELD rel AS r1
-                CALL apoc.merge.relationship(n2, row.reverse_type, {}, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}, n1, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}) YIELD rel AS r2
+                CALL apoc.merge.node([row.START_LABEL], {key:row.START_KEY}) YIELD node AS n1
+                CALL apoc.merge.node([row.END_LABEL], {key:row.END_KEY}) YIELD node AS n2
+                CALL apoc.merge.relationship(n1, row.TYPE, {}, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}, n2, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}) YIELD rel AS r1
+                CALL apoc.merge.relationship(n2, row.REVERSE_TYPE, {}, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}, n1, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}) YIELD rel AS r2
                 RETURN n1.key, n2.key
             ', {batchSize: $batch_size, parallel: False, params: { rows: $batch, tag: $publish_tag }})
         """
